---
name: "[BUG]"
about: Create a report to help us improve
title: "[BUG] Bug report"
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.


**Desktop (please complete the following information):**
 - OS: [e.g. OS X Catalina]
 - scikit-hts version: [e.g. 0.2.1]
- Python version: [e.g. 3.7.4]

**Additional context**
Add any other context about the problem here.
